# Asulum Claims python package

## Required modules

- bs4
- requests
- pandas
- feather-format
- numpy
- argparse
- pypiwin32
- regex
- pyodbc

Install via pip

```bash
python -m pip wddasylumclaims
```

This will download all the required modules and install wddasylumclaims

## Run

Run script using:

```bash
python -m wddasylumclaims [optional arguments]
```

For help with optional arguments:

```bash
python -m wddasylumclaims -h
```
